dummy_operator — Airflow Documentation

# Source code for dummy_operator

    # -*- coding: utf-8 -*-
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing, software
    # distributed under the License is distributed on an "AS IS" BASIS,
    # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    # See the License for the specific language governing permissions and
    # limitations under the License.

    from airflow.models import BaseOperator
    from airflow.utils.decorators import apply_defaults

    class DummyOperator(BaseOperator):
        """
        Operator that does literally nothing. It can be used to group tasks in a
        DAG.
        """

        template_fields = tuple()
        ui_color = '#e8f7e4'

        @apply_defaults
        def __init__(self, *args, **kwargs):
            super(DummyOperator, self).__init__(*args, **kwargs)

        def execute(self, context):
            pass